==> tree_distance-0.0.2.tar.gz: tree_distance-0.0.2/Tools.cpp <==
#include "Tools.h"
#include <iomanip>
//#include <sstream>
#define PRECISION 5

std::vector<std::string> Tools::string_split(std::string& to_split, const std::string& delimiters, const std::string& to_trim) {
    std::vector<std::string> results;
    boost::trim_if(to_split, boost::is_any_of(to_trim));
    boost::split(results, to_split, boost::is_any_of(delimiters), boost::token_compress_on);
    return results;
}

std::vector<std::string> Tools::string_split(std::string& to_split, const char* delimiters, const char* to_trim) {
    std::vector<std::string> results;
    boost::trim_if(to_split, boost::is_any_of(to_trim));
    boost::split(results, to_split, boost::is_any_of(delimiters), boost::token_compress_on);
    return results;
}

std::vector<double> Tools::stringvec_to_doublevec(std::vector<std::string> stringvec) {
    std::vector<double> doublevec(stringvec.size());
    std::transform(stringvec.begin(), stringvec.end(), doublevec.begin(), [](const std::string &val) {
        try {
            return std::stod(val);
        }
        catch (const std::invalid_argument &ia) {
            throw std::invalid_argument("invalid argument: " + val);
        }
    });
    return doublevec;
}

std::string Tools::string_join(std::vector<std::string> to_join, std::string delimiter) {
    return boost::algorithm::join(to_join, delimiter);
}

std::string Tools::string_join(std::deque<std::string> to_join, std::string delimiter) {
    return boost::algorithm::join(to_join, delimiter);
}

std::string Tools::double_to_string(double d) {
    std::ostringstream ss;
    ss << std::fixed << std::setprecision(PRECISION);
    ss << d;
    std::string s = ss.str();
    return s;
}

//size_t Tools::nextIndex(string const &t, size_t i, string s) {
//    size_t pos = t.find_first_of(s, i + 1);
//    return pos == std::string::npos ? t.size() : pos;
//}

string Tools::substring(string s, size_t begin, size_t end) {
    if (begin > end) throw std::invalid_argument("'begin' can't be larger than 'end'");
    try {
        return s.substr(begin, end - begin);
    }
    catch (std::out_of_range &range_error) {
        return "";
    }
}

void Tools::despace(string &s) {
    s.erase(std::remove_if(s.begin(), s.end(), [](char x){return std::isspace(x);}), s.end());
}

size_t Tools::nextIndex(const string &t, size_t i, const char *s) {
    size_t pos = t.find_first_of(s, i + 1);
    return pos == std::string::npos ? t.size() : pos;
}

==> tree_distance-0.0.5.tar.gz: tree_distance-0.0.5/Tools.cpp <==
#include "Tools.h"
#include <iomanip>
//#include <sstream>
#define PRECISION 5

std::vector<std::string> Tools::string_split(std::string &to_split, const std::string &delimiters, const std::string &to_trim) {
    std::vector<std::string> results;
    boost::trim_if(to_split, boost::is_any_of(to_trim));
    boost::split(results, to_split, boost::is_any_of(delimiters), boost::token_compress_on);
    return results;
}

std::vector<std::string> Tools::string_split(std::string &to_split, const char *delimiters, const char *to_trim) {
    std::vector<std::string> results;
    boost::trim_if(to_split, boost::is_any_of(to_trim));
    boost::split(results, to_split, boost::is_any_of(delimiters), boost::token_compress_on);
    return results;
}

std::vector<double> Tools::stringvec_to_doublevec(std::vector<std::string> stringvec) {
    std::vector<double> doublevec(stringvec.size());
    std::transform(stringvec.begin(), stringvec.end(), doublevec.begin(), [](const std::string &val) {
        try {
            return std::stod(val);
        }
        catch (const std::invalid_argument &ia) {
            throw std::invalid_argument("invalid argument: " + val);
        }
    });
    return doublevec;
}

std::string Tools::string_join(std::vector<std::string> to_join, std::string delimiter) {
    return boost::algorithm::join(to_join, delimiter);
}

std::string Tools::string_join(std::deque<std::string> to_join, std::string delimiter) {
    return boost::algorithm::join(to_join, delimiter);
}

std::string Tools::double_to_string(double d) {
    std::ostringstream ss;
    ss << std::fixed << std::setprecision(PRECISION);
    ss << d;
    std::string s = ss.str();
    return s;
}

//size_t Tools::nextIndex(string const &t, size_t i, string s) {
//    size_t pos = t.find_first_of(s, i + 1);
//    return pos == std::string::npos ? t.size() : pos;
//}

string Tools::substring(string s, size_t begin, size_t end) {
    if (begin > end) throw std::invalid_argument("'begin' can't be larger than 'end'");
    try {
        return s.substr(begin, end - begin);
    }
    catch (std::out_of_range &range_error) {
        return "";
    }
}

void Tools::despace(string &s) {
    s.erase(std::remove_if(s.begin(), s.end(), [](char x) {
        return std::isspace(x);
    }), s.end());
}

size_t Tools::nextIndex(const string &t, size_t i, const char *s) {
    size_t pos = t.find_first_of(s, i + 1);
    return pos == std::string::npos ? t.size() : pos;
}
